@@ -21,8 +21,8 @@ class BidsRule(ValidationRule):
         if self.min_bid is None and self.max_bid is None:
             return
 
-        if self.min_bid >= self.max_bid:
-            raise ValidationException("min_bid must be less than max_bid")
+        if self.min_bid > self.max_bid:
+            raise ValidationException("min_bid must be less or equal to max_bid")
 
         T1AmountRanges(type_ranges=StrategyMinBidRanges,
                        amount=self.min_bid,
